from wiser.gcloud.services.storage import Storage

__all__ = ["Storage"]
